==> nextcloud-29.0.12.tgz: nextcloud/apps/workflowengine/l10n/nl.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "De opgegeven operator is ongeldig",
    "The given regular expression is invalid" : "De opgegeven reguliere expressie is ongeldig",
    "The given file size is invalid" : "De opgegeven bestandsgrootte is ongeldig",
    "The given tag id is invalid" : "De opgegeven markerings-id is ongeldig",
    "The given IP range is invalid" : "De opgegeven IP-range is ongeldig",
    "The given IP range is not valid for IPv4" : "De opgegeven IP-range is niet geldig voor IPv4",
    "The given IP range is not valid for IPv6" : "De opgegeven IP-range is niet geldig voor IPv6",
    "The given time span is invalid" : "De opgegeven tijdspanne is ongeldig",
    "The given start time is invalid" : "De opgegeven begintijd is ongeldig",
    "The given end time is invalid" : "De opgegeven eindtijd is ongeldig",
    "The given group does not exist" : "De opgegeven groep bestaat niet",
    "File" : "Bestand",
    "File created" : "Bestand aangemaakt",
    "File updated" : "Bestand bijgewerkt",
    "File renamed" : "Bestand hernoemd",
    "File deleted" : "Bestand verwijderd",
    "File accessed" : "Bestand benaderd",
    "File copied" : "Bestand gekopieerd",
    "Tag assigned" : "Tag toegewezen",
    "Someone" : "Iemand",
    "%s created %s" : "%s creëerde %s",
    "%s modified %s" : "%s wijzigde %s",
    "%s deleted %s" : "%s verwijderde %s",
    "%s accessed %s" : "%s opende %s",
    "%s renamed %s" : "%s hernoemde %s",
    "%s copied %s" : "%s kopieerde %s",
    "%s assigned %s to %s" : "%s wees %s toe aan %s",
    "Operation #%s does not exist" : "Bewerking #%s bestaat niet",
    "Entity %s does not exist" : "Entiteit %s bestaat niet",
    "Entity %s is invalid" : "Entiteit %s is ongeldig",
    "No events are chosen." : "Nog geen gebeurtenissen gekozen.",
    "Entity %s has no event %s" : "Entiteit %s heeft geen gebeurtenis %s",
    "Operation %s does not exist" : "Bewerking %s bestaat niet",
    "Operation %s is invalid" : "Bewerking %s is ongeldig",
    "At least one check needs to be provided" : "Minstens één controle moet worden opgegeven",
    "The provided operation data is too long" : "De opgegeven bewerkingsgegevens zijn te lang",
    "Invalid check provided" : "Ongeldige controle opgegeven",
    "Check %s does not exist" : "Controleer: %s bestaat niet",
    "Check %s is invalid" : "Controleer: %s is ongeldig",
    "Check %s is not allowed with this entity" : "Controle %s is niet toegestaan met deze waarde",
    "The provided check value is too long" : "Het opgegeven controlegetal is te lang",
    "Check #%s does not exist" : "Controleer: #%s bestaat niet",
    "Check %s is invalid or does not exist" : "Controleer: %s is ongeldig of bestaat niet",
    "Flow" : "Flow",
    "Nextcloud workflow engine" : "Nextcloud workflow engine",
    "Select a filter" : "Selecteer een filter",
    "Select a comparator" : "Selecteer een comparator",
    "Remove filter" : "Verwijder filter",
    "Select a file type" : "Selecteer een bestandstype",
    "e.g. httpd/unix-directory" : "bijv. httpd/unix-directory",
    "Folder" : "Map",
    "Images" : "Afbeeldingen",
    "Office documents" : "Office documenten",
    "PDF documents" : "PDF documenten",
    "Custom MIME type" : "Maatwerk mimetype",
    "Custom mimetype" : "Maatwerk mimetype",
    "Please enter a valid time span" : "Geef een geldige tijdsinterval op",
    "Select a request URL" : "Selecteer een aanvraag URL",
    "Files WebDAV" : "Bestanden WebDAV",
    "Custom URL" : "Maatwerk URL",
    "Select a user agent" : "Selecteer een 'user agent'",
    "Android client" : "Android client",
    "iOS client" : "iOS client",
    "Desktop client" : "Desktop client",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
    "Custom user agent" : "Aangepaste 'user agent'",
    "Select groups" : "Selecteer groepen",
    "Groups" : "Groepen",
    "Select a trigger" : "Selecteer een trigger",
    "At least one event must be selected" : "Er moet minimaal één gebeurtenis worden geselecteerd",
    "Add new flow" : "Nieuwe flow toevoegen",
    "When" : "Wanneer",
    "and" : "en",
    "Add a new filter" : "Nieuw filter toevoegen",
    "Cancel" : "Annuleren",
    "Delete" : "Verwijderen",
    "The configuration is invalid" : "De configuratie is ongeldig",
    "Active" : "Actief",
    "Save" : "Opslaan",
    "Available flows" : "Beschikbare flows",
    "For details on how to write your own flow, check out the development documentation." : "Raadpleeg de ontwikkeldocumentatie voor meer informatie over het ontwikkelen van je eigen flow.",
    "More flows" : "Meer flows",
    "Browse the App Store" : "Blader door de App Store",
    "Show less" : "Toon minder",
    "Show more" : "Toon meer",
    "Configured flows" : "Geconfigureerde flows",
    "Your flows" : "Jouw flows",
    "matches" : "komt overeen",
    "does not match" : "komt niet overeen",
    "is" : "is",
    "is not" : "is niet",
    "File name" : "Bestandsnaam",
    "File MIME type" : "Mimetype bestand",
    "File size (upload)" : "Bestandsgrootte (upload)",
    "less" : "minder",
    "less or equals" : "minder of gelijk",
    "greater or equals" : "groter of gelijk",
    "greater" : "groter",
    "Request remote address" : "Extern adres aanvraag",
    "matches IPv4" : "komt overeen met IPv4",
    "does not match IPv4" : "komt niet overeen met IPv4",
    "matches IPv6" : "komt overeen met IPv6",
    "does not match IPv6" : "komt niet overeen met IPv6",
    "File system tag" : "Bestandssysteem markering",
    "is tagged with" : "is gemarkeerd met",
    "is not tagged with" : "is niet gemarkeerd met",
    "Request URL" : "URL aanvraag",
    "Request time" : "Tijdstip aanvraag",
    "between" : "tussen",
    "not between" : "niet tussen",
    "Request user agent" : "Useragent aanvraag",
    "is member of" : "is lid van",
    "is not member of" : "is geen lid van"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.10.tgz: nextcloud/apps/workflowengine/l10n/nl.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "De opgegeven operator is ongeldig",
    "The given regular expression is invalid" : "De opgegeven reguliere expressie is ongeldig",
    "The given file size is invalid" : "De opgegeven bestandsgrootte is ongeldig",
    "The given tag id is invalid" : "De opgegeven markerings-id is ongeldig",
    "The given IP range is invalid" : "De opgegeven IP-range is ongeldig",
    "The given IP range is not valid for IPv4" : "De opgegeven IP-range is niet geldig voor IPv4",
    "The given IP range is not valid for IPv6" : "De opgegeven IP-range is niet geldig voor IPv6",
    "The given time span is invalid" : "De opgegeven tijdspanne is ongeldig",
    "The given start time is invalid" : "De opgegeven begintijd is ongeldig",
    "The given end time is invalid" : "De opgegeven eindtijd is ongeldig",
    "The given group does not exist" : "De opgegeven groep bestaat niet",
    "File" : "Bestand",
    "File created" : "Bestand aangemaakt",
    "File updated" : "Bestand bijgewerkt",
    "File renamed" : "Bestand hernoemd",
    "File deleted" : "Bestand verwijderd",
    "File accessed" : "Bestand benaderd",
    "File copied" : "Bestand gekopieerd",
    "Tag assigned" : "Tag toegewezen",
    "Someone" : "Iemand",
    "%s created %s" : "%s creëerde %s",
    "%s modified %s" : "%s wijzigde %s",
    "%s deleted %s" : "%s verwijderde %s",
    "%s accessed %s" : "%s opende %s",
    "%s renamed %s" : "%s hernoemde %s",
    "%s copied %s" : "%s kopieerde %s",
    "%s assigned %s to %s" : "%s wees %s toe aan %s",
    "Operation #%s does not exist" : "Bewerking #%s bestaat niet",
    "Entity %s does not exist" : "Entiteit %s bestaat niet",
    "Entity %s is invalid" : "Entiteit %s is ongeldig",
    "No events are chosen." : "Nog geen gebeurtenissen gekozen.",
    "Entity %s has no event %s" : "Entiteit %s heeft geen gebeurtenis %s",
    "Operation %s does not exist" : "Bewerking %s bestaat niet",
    "Operation %s is invalid" : "Bewerking %s is ongeldig",
    "At least one check needs to be provided" : "Minstens één controle moet worden opgegeven",
    "The provided operation data is too long" : "De opgegeven bewerkingsgegevens zijn te lang",
    "Invalid check provided" : "Ongeldige controle opgegeven",
    "Check %s does not exist" : "Controleer: %s bestaat niet",
    "Check %s is invalid" : "Controleer: %s is ongeldig",
    "Check %s is not allowed with this entity" : "Controle %s is niet toegestaan met deze waarde",
    "The provided check value is too long" : "Het opgegeven controlegetal is te lang",
    "Check #%s does not exist" : "Controleer: #%s bestaat niet",
    "Check %s is invalid or does not exist" : "Controleer: %s is ongeldig of bestaat niet",
    "Flow" : "Flow",
    "Nextcloud workflow engine" : "Nextcloud workflow engine",
    "Select a filter" : "Selecteer een filter",
    "Select a comparator" : "Selecteer een comparator",
    "Remove filter" : "Verwijder filter",
    "Audio" : "Geluid",
    "Folder" : "Map",
    "Images" : "Afbeeldingen",
    "Office documents" : "Office documenten",
    "PDF documents" : "PDF documenten",
    "Video" : "Video",
    "Custom MIME type" : "Maatwerk mimetype",
    "Custom mimetype" : "Maatwerk mimetype",
    "Select a file type" : "Selecteer een bestandstype",
    "e.g. httpd/unix-directory" : "bijv. httpd/unix-directory",
    "Please enter a valid time span" : "Geef een geldige tijdsinterval op",
    "Files WebDAV" : "Bestanden WebDAV",
    "Custom URL" : "Maatwerk URL",
    "Select a request URL" : "Selecteer een aanvraag URL",
    "Android client" : "Android client",
    "iOS client" : "iOS client",
    "Desktop client" : "Desktop client",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
    "Custom user agent" : "Aangepaste 'user agent'",
    "Select a user agent" : "Selecteer een 'user agent'",
    "Select groups" : "Selecteer groepen",
    "Groups" : "Groepen",
    "Select a trigger" : "Selecteer een trigger",
    "At least one event must be selected" : "Er moet minimaal één gebeurtenis worden geselecteerd",
    "Add new flow" : "Nieuwe flow toevoegen",
    "The configuration is invalid" : "De configuratie is ongeldig",
    "Active" : "Actief",
    "Save" : "Opslaan",
    "When" : "Wanneer",
    "and" : "en",
    "Add a new filter" : "Nieuw filter toevoegen",
    "Cancel" : "Annuleren",
    "Delete" : "Verwijderen",
    "Available flows" : "Beschikbare flows",
    "For details on how to write your own flow, check out the development documentation." : "Raadpleeg de ontwikkeldocumentatie voor meer informatie over het ontwikkelen van je eigen flow.",
    "No flows installed" : "Geen flows geïnstalleerd",
    "Ask your administrator to install new flows." : "Vraag de beheerder om nieuwe flows te installeren.",
    "More flows" : "Meer flows",
    "Browse the App Store" : "Blader door de App Store",
    "Show less" : "Toon minder",
    "Show more" : "Toon meer",
    "Configured flows" : "Geconfigureerde flows",
    "Your flows" : "Jouw flows",
    "No flows configured" : "Geen flows geconfigureerd",
    "matches" : "komt overeen",
    "does not match" : "komt niet overeen",
    "is" : "is",
    "is not" : "is niet",
    "File name" : "Bestandsnaam",
    "File MIME type" : "Mimetype bestand",
    "File size (upload)" : "Bestandsgrootte (upload)",
    "less" : "minder",
    "less or equals" : "minder of gelijk",
    "greater or equals" : "groter of gelijk",
    "greater" : "groter",
    "Request remote address" : "Extern adres aanvraag",
    "matches IPv4" : "komt overeen met IPv4",
    "does not match IPv4" : "komt niet overeen met IPv4",
    "matches IPv6" : "komt overeen met IPv6",
    "does not match IPv6" : "komt niet overeen met IPv6",
    "File system tag" : "Bestandssysteem markering",
    "is tagged with" : "is gemarkeerd met",
    "is not tagged with" : "is niet gemarkeerd met",
    "Request URL" : "URL aanvraag",
    "Request time" : "Tijdstip aanvraag",
    "between" : "tussen",
    "not between" : "niet tussen",
    "Request user agent" : "Useragent aanvraag",
    "Group membership" : "Groepslidmaatschap",
    "is member of" : "is lid van",
    "is not member of" : "is geen lid van",
    "Type to search for group …" : "Type om groep te zoeken …"
},
"nplurals=2; plural=(n != 1);");
